.. code-block:: console

    $ manga_dap_inspector -h
    usage: manga_dap_inspector [-h] [--maps_file MAPS_FILE]
                               [--model_file MODEL_FILE] [--ext [EXT ...]]
                               [--maskspec]
    
    Inspect results of the MaNGA DAP
    
    optional arguments:
      -h, --help            show this help message and exit
      --maps_file MAPS_FILE
                            Output MAPS file (default: None)
      --model_file MODEL_FILE
                            Output LOGCUBE model file (default: None)
      --ext [EXT ...]       List of map extensions to include (default: None)
      --maskspec            Use masks for spectra. (default: False)
    